@@ -119,6 +119,7 @@ indi_to_list_string (NODE indi, NODE fam, INT len, RFMT rfmt, BOOLEAN appkey)
 	} else
 		name = _(qSunksps);
 	sprintf(p, "%s", name);
+	/* TODO: Shouldn't we len -= strlen(p) first ? Perry, 2007-09-29 */
 	p += strlen(p);
 	if (fam)  evt = fam_to_event(fam, "MARR", _(qSdspa_mar), len, rfmt);
 	if (!evt) evt = indi_to_event(indi, "BIRT", _(qSdspa_bir), len, rfmt);
@@ -159,8 +160,7 @@ indi_to_list_string (NODE indi, NODE fam, INT len, RFMT rfmt, BOOLEAN appkey)
 		*p = '\0';
 	    }
 	}
-	if ((INT)strlen(scratch) > len)
-		scratch[len] = 0;
+	limit_width(scratch, len, uu8);
 	return strsave(scratch);
 }
 /*================================================
@@ -194,6 +194,7 @@ sour_to_list_string (NODE sour, INT len, STRING delim)
 		llstrcatn(&p, delim, &mylen);
 		llstrcatn(&p, name, &mylen);
 	}
+	limit_width(scratch, len, uu8);
 	return strsave(scratch);
 }
 /*================================================
@@ -222,6 +223,7 @@ even_to_list_string (NODE even, INT len, STRING delim)
                 llstrcatn(&p, name, &mylen);
 		llstrcatn(&p, ")", &mylen);
 	}
+	limit_width(scratch, len, uu8);
 	return strsave(scratch);
 }
 /*================================================
@@ -283,6 +285,7 @@ fam_to_list_string (NODE fam, INT len, STRING delim)
 	}
 	join_fam(fam, refn, husb, wife, chil, rest);
 	/* TO DO - print a husband and a wife out */
+	limit_width(scratch, len, uu8);
 	return strsave(scratch);
 }
 /*================================================
@@ -331,6 +334,7 @@ other_to_list_string(NODE node, INT len, STRING delim)
 		else
 			break;
 	}
+	limit_width(scratch, len, uu8);
 	return strsave(scratch);
 }
 /*===========================================
