@@ -21,7 +21,6 @@
    CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
    SOFTWARE.
 */
-/* modified 05 Jan 2000 by Paul B. McBride (pmcbride@tiac.net) */
 
 #ifndef _LL_STDLIB_H
 #define _LL_STDLIB_H
@@ -43,6 +42,7 @@
 
 /* Current internal codeset (the same as that of the loaded database). */
 extern BOOLEAN uu8;         /* flag set if int_codeset is UTF-8 */
+extern BOOLEAN gui8;        /* flag if display output encoding is UTF-8 */
 extern STRING  int_codeset;
 
 /* appendstr.c */
@@ -208,11 +208,14 @@ void set_utf8_casing(ZSTR (*ufnc)(CNSTRING), ZSTR (*lfnc)(CNSTRING));
 STRING upperascii_s(STRING str);
 
 /* strutf8.c */
+void chopstr_utf8(STRING str, size_t index, BOOLEAN utf8);
+void limit_width(STRING str, size_t width, BOOLEAN utf8);
 STRING find_prev_char(STRING ptr, INT * width, STRING limit, int utf8);
-INT utf8len(char ch);
 INT next_char32(STRING * ptr, int utf8);
 void skip_BOM(STRING * pstr);
+size_t str8chlen(CNSTRING str);
 void unicode_to_utf8(INT wch, char * utf8);
+INT utf8len(char ch);
 
 /* strwhite.c */
 BOOLEAN allwhite(STRING);
