@@ -12,7 +12,7 @@
 #include "llstdlib.h"
 
 /*==============================
- * utf8len -- Length of a utf-8 character
+ * utf8len -- Length of a UTF-8 character
  *  ch: [in] starting byte
  * Created: 2001/08/02 (Perry Rapp)
  *============================*/
@@ -20,7 +20,7 @@ INT
 utf8len (char ch)
 {
 	/* test short cases first, as probably much more common */
-	if (!(ch & 0x80 && ch & 0x40))
+	if (!((ch & 0x80) && (ch & 0x40)))
 		return 1; /* not a multibyte lead byte */
 	if (!(ch & 0x20))
 		return 2;
@@ -32,6 +32,31 @@ utf8len (char ch)
 		return 5;
 	return 6;
 }
+/*==============================
+ * str8chlen -- Length of a UTF-8 string in characters
+ * Created: 2001/08/02 (Perry Rapp)
+ *============================*/
+size_t
+str8chlen (CNSTRING str)
+{
+	CNSTRING ptr = str;
+	size_t len = 0;
+	size_t chwidth = 0;
+	size_t i=0;
+	while (*ptr) {
+		chwidth = utf8len(*ptr);
+		++len;
+		/* advance pointer, but be careful
+		not to skip blindly over null in middle
+		of broken multibyte sequence */
+		for (i=0; i<chwidth; ++i) {
+			if (!ptr[0])
+				return len;
+			++ptr;
+		}
+	}
+	return len;
+}
 /*=========================================
  * find_prev_char -- Back up to start of previous character.
  * Return pointer to start of previous character,
@@ -40,6 +65,8 @@ utf8len (char ch)
  * If limit is non-zero, don't back up beyond this.
  * This will set *width=0 if it gets back to limit without 
  *  finding valid character, or backs up more than 6 characters
+ * Warning: return width + pointer may exceed lenght of string
+ *  if input was pointing at partial multibyte at end (broken string)
  * Created: 2002/06/12, Perry Rapp
  *=======================================*/
 STRING
@@ -55,13 +82,12 @@ find_prev_char (STRING ptr, INT * width, STRING limit, int utf8)
 			--ptr;
 			if (init - ptr == 7)
 				break;
-			if (*ptr & 0x80)
+			/* if UTF-8 trail byte, keep backing up */
+			if ((*ptr & 0x80) && !(*ptr & 0x40))
 				continue;
 			tmp = utf8len(*ptr);
-			if (tmp <= init-ptr) {
-				len = tmp;
-				break;
-			}
+			len = tmp;
+			break;
 		}
 	} else {
 		if (ptr != limit) {
@@ -200,4 +226,28 @@ unicode_to_utf8 (INT wch, char * utf8)
 	}
 	*lpd++ = 0;
 }
-
+/*=========================================
+ * chopstr_utf8 -- chop string at specified byte index
+ * Eg, chopstr_utf8("abc", 2, x) results in "ab"
+ * If UTF-8, backs up as necessary to avoid leaving
+ * broken multibyte at end
+ *=======================================*/
+void
+chopstr_utf8 (STRING str, size_t index, BOOLEAN utf8)
+{
+	INT width=0, i=0;
+	STRING prev = find_prev_char(&str[index+1], &width, str, utf8);
+	prev[0] = 0;
+	/* We don't zero out entire width in case it is outside of
+	string range, in case caller passed us a broken string */
+}
+/*=========================================
+ * limit_width -- chop string if longer than specified width
+ *  handles UTF-8
+ *=======================================*/
+void
+limit_width (STRING str, size_t width, BOOLEAN utf8)
+{
+	if (strlen(str) < width) return;
+	chopstr_utf8(str, width-1, utf8);
+}
\ No newline at end of file
